==> zio-aws-ssm_3-5.17.124.1-sources.jar: zio/aws/ssm/model/DescribeMaintenanceWindowsRequest.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.{NextToken, MaintenanceWindowMaxResults}
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeMaintenanceWindowsRequest(
    filters: Option[Iterable[zio.aws.ssm.model.MaintenanceWindowFilter]] = None,
    maxResults: Option[MaintenanceWindowMaxResults] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest = {
    import DescribeMaintenanceWindowsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value =>
          MaintenanceWindowMaxResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.DescribeMaintenanceWindowsRequest.ReadOnly =
    zio.aws.ssm.model.DescribeMaintenanceWindowsRequest.wrap(buildAwsValue())
}
object DescribeMaintenanceWindowsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.DescribeMaintenanceWindowsRequest =
      zio.aws.ssm.model.DescribeMaintenanceWindowsRequest(
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def filters
        : Option[List[zio.aws.ssm.model.MaintenanceWindowFilter.ReadOnly]]
    def maxResults: Option[MaintenanceWindowMaxResults]
    def nextToken: Option[NextToken]
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.ssm.model.MaintenanceWindowFilter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, MaintenanceWindowMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest
  ) extends zio.aws.ssm.model.DescribeMaintenanceWindowsRequest.ReadOnly {
    override val filters
        : Option[List[zio.aws.ssm.model.MaintenanceWindowFilter.ReadOnly]] =
      scala
        .Option(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ssm.model.MaintenanceWindowFilter.wrap(item)
          }.toList
        )
    override val maxResults: Option[MaintenanceWindowMaxResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.ssm.model.primitives.MaintenanceWindowMaxResults(value)
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.ssm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest
  ): zio.aws.ssm.model.DescribeMaintenanceWindowsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ssm_3-5.17.166.2-sources.jar: zio/aws/ssm/model/DescribeMaintenanceWindowsRequest.scala <==
package zio.aws.ssm.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import zio.aws.ssm.model.primitives.{NextToken, MaintenanceWindowMaxResults}
import scala.jdk.CollectionConverters.*
final case class DescribeMaintenanceWindowsRequest(
    filters: Optional[Iterable[zio.aws.ssm.model.MaintenanceWindowFilter]] =
      Optional.Absent,
    maxResults: Optional[MaintenanceWindowMaxResults] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest = {
    import DescribeMaintenanceWindowsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value =>
          MaintenanceWindowMaxResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.DescribeMaintenanceWindowsRequest.ReadOnly =
    zio.aws.ssm.model.DescribeMaintenanceWindowsRequest.wrap(buildAwsValue())
}
object DescribeMaintenanceWindowsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.DescribeMaintenanceWindowsRequest =
      zio.aws.ssm.model.DescribeMaintenanceWindowsRequest(
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def filters
        : Optional[List[zio.aws.ssm.model.MaintenanceWindowFilter.ReadOnly]]
    def maxResults: Optional[MaintenanceWindowMaxResults]
    def nextToken: Optional[NextToken]
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.ssm.model.MaintenanceWindowFilter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, MaintenanceWindowMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest
  ) extends zio.aws.ssm.model.DescribeMaintenanceWindowsRequest.ReadOnly {
    override val filters
        : Optional[List[zio.aws.ssm.model.MaintenanceWindowFilter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ssm.model.MaintenanceWindowFilter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[MaintenanceWindowMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ssm.model.primitives.MaintenanceWindowMaxResults(value)
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ssm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.DescribeMaintenanceWindowsRequest
  ): zio.aws.ssm.model.DescribeMaintenanceWindowsRequest.ReadOnly = new Wrapper(
    impl
  )
}
